@@ -75,7 +75,7 @@ def ser_read(f, n):
     functions.
     """
     if n > MAX_SIZE:
-        raise SerializationError('Asked to read 0x%x bytes; MAX_SIZE exceeded')
+        raise SerializationError('Asked to read 0x%x bytes; MAX_SIZE exceeded' % n)
     r = f.read(n)
     if len(r) < n:
         raise SerializationTruncationError('Asked to read %i bytes, but only got %i' % (n, len(r)))
@@ -311,9 +311,30 @@ def uint256_from_compact(c):
     Used for the nBits compact encoding of the target in the block header.
     """
     nbytes = (c >> 24) & 0xFF
-    v = (c & 0xFFFFFF) << (8 * (nbytes - 3))
+    if nbytes <= 3:
+        v = (c & 0xFFFFFF) >> 8 * (3 - nbytes)
+    else:
+        v = (c & 0xFFFFFF) << (8 * (nbytes - 3))
     return v
 
+def compact_from_uint256(v):
+    """Convert uint256 to compact encoding
+    """
+    nbytes = (v.bit_length() + 7) >> 3
+    compact = 0
+    if nbytes <= 3:
+        compact = (v & 0xFFFFFF) << 8 * (3 - nbytes)
+    else:
+        compact = v >> 8 * (nbytes - 3)
+        compact = compact & 0xFFFFFF
+
+    # If the sign bit (0x00800000) is set, divide the mantissa by 256 and
+    # increase the exponent to get an encoding without it set.
+    if compact & 0x00800000:
+        compact >>= 8
+        nbytes += 1
+
+    return compact | nbytes << 24
 
 def uint256_to_shortstr(u):
     s = "%064x" % (u,)
@@ -339,5 +360,6 @@ __all__ = (
         'VarStringSerializer',
         'uint256_from_str',
         'uint256_from_compact',
+        'compact_from_uint256',
         'uint256_to_shortstr',
 )
